from setuptools import setup
__version__ = 0.2

setup(
    name='licenses',
    version=__version__,

    # general metadata
    description='List of open (http://opensource.org/, http://opendefinition.org/) licenses',
    license='PD',
    author='Open Knowledge Foundation',
    author_email='info@okfn.org',
    url='http://www.knowledgeforge.net/okfn/licenses/',
    py_modules=['licenses'],
)
